==> haskell-ansi-terminal0.11-0.11.5-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal0.11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal
version:              0.11.5
visibility:           public
id:                   ansi-terminal-0.11.5-GmxlGl1eC6rGTjWL8Yprft
key:                  ansi-terminal-0.11.5-GmxlGl1eC6rGTjWL8Yprft
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  a9a915c9d8daa70efac402cc0a89f4bf
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-2G5GysvLvQ11TJQD7M2JXs:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal0.11
hs-libraries:         HSansi-terminal-0.11.5-GmxlGl1eC6rGTjWL8Yprft
depends:
    ansi-terminal-types-0.11.5-2G5GysvLvQ11TJQD7M2JXs base-4.16.4.0
    colour-2.3.6-KDhjTRIL7rnBhoKfQ21QbO

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal0.11/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal0.11/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal0.11-0.11.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal0.11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal
version:              0.11.5
visibility:           public
id:                   ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
key:                  ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  c7aefee62e044ed7b419c0099105d8d7
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-LNO5pMGBCOpKOnVwNRUhhM:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal0.11
hs-libraries:         HSansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE
depends:
    ansi-terminal-types-0.11.5-LNO5pMGBCOpKOnVwNRUhhM base-4.16.4.0
    colour-2.3.6-HdI1cmU1Wok1ucyzh0SdSS

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal0.11/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal0.11/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
